@@ -17,7 +17,7 @@
 #include <asm/unistd.h>
 
 #ifndef __NR_set_ipv4root
-	#define __NR_set_ipv4root	223
+	#define __NR_set_ipv4root	227
 #endif
 
 _syscall1(int, set_ipv4root, unsigned long, ip);
@@ -29,6 +29,33 @@ static void usage()
 	exit (-1);
 }
 
+/*
+	Check if a network device exist in /proc/net/dev.
+	This is used because ifconfig_ioctl triggers modprobe if requesting
+	information about non existant devices.
+
+	Return != 0 if the device exist.
+*/
+static int chbind_devexist (const char *dev)
+{
+	int ret = 0;
+	FILE *fin = fopen ("/proc/net/dev","r");
+	if (fin != NULL){
+		int len = strlen(dev);
+		char buf[1000];
+		fgets(buf,sizeof(buf)-1,fin);	// Skip one line
+		while (fgets(buf,sizeof(buf)-1,fin)!=NULL){
+			const char *pt = strstr(buf,dev);
+			if (pt != NULL && pt[len] == ':'){
+				ret = 1;
+				break;
+			}
+		}
+		fclose (fin);
+	}
+	return ret;
+}
+
 
 static int ifconfig_ioctl(
 	int fd,
@@ -50,16 +77,18 @@ int ifconfig_getaddr (
 	unsigned long *addr)
 {
 	int ret = -1;
-	int skfd = socket(AF_INET, SOCK_DGRAM, 0);
-	*addr = 0;
-	if (skfd != -1){
-		struct ifreq ifr;
-		if (ifconfig_ioctl(skfd,ifname,SIOCGIFADDR, &ifr) >= 0){
-			struct sockaddr_in *sin = (struct sockaddr_in*)&ifr.ifr_addr;
-			*addr = sin->sin_addr.s_addr;
-			ret = 0;
+	if (chbind_devexist(ifname)){
+		int skfd = socket(AF_INET, SOCK_DGRAM, 0);
+		*addr = 0;
+		if (skfd != -1){
+			struct ifreq ifr;
+			if (ifconfig_ioctl(skfd,ifname,SIOCGIFADDR, &ifr) >= 0){
+				struct sockaddr_in *sin = (struct sockaddr_in*)&ifr.ifr_addr;
+				*addr = sin->sin_addr.s_addr;
+				ret = 0;
+			}
+			close (skfd);
 		}
-		close (skfd);
 	}
 	return ret;
 }
